"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.normalizeExecutableCode = normalizeExecutableCode;
exports.normalizeItemOrArray = normalizeItemOrArray;
exports.formatObjectToFormattedJsString = formatObjectToFormattedJsString;
exports.formatArrayToLinesOfJsString = formatArrayToLinesOfJsString;
exports.formatArrayToJSArray = formatArrayToJSArray;
function normalizeExecutableCode(executableCode) {
    const { fileImports: rawFileImports, codeStrings: rawCodeStrings } = executableCode;
    return {
        fileImports: normalizeItemOrArray(rawFileImports),
        codeStrings: normalizeItemOrArray(rawCodeStrings),
    };
}
function normalizeItemOrArray(itemOrArray) {
    if (itemOrArray == null) {
        return undefined;
    }
    if (Array.isArray(itemOrArray)) {
        return itemOrArray;
    }
    return [itemOrArray];
}
// Return a formatted JSON in TS object with the same keys as the input object but remove the " for the properties
function formatObjectToFormattedJsString(jsonObj) {
    if (!jsonObj) {
        return;
    }
    // Convert JSON object to a string with indentation
    const jsonString = JSON.stringify(jsonObj, null, 2);
    // Remove double quotes around property names
    return jsonString.replace(/"(\w+)":/g, '$1:');
}
function formatArrayToLinesOfJsString(lines, separator = '\n') {
    if (lines == null || lines.length === 0) {
        return;
    }
    return lines.join(separator).replace(/'/g, '"');
}
function formatArrayToJSArray(lines) {
    if (!Array.isArray(lines)) {
        return;
    }
    return `[${formatArrayToLinesOfJsString(lines, ',\n') ?? ''}]`.replace(/"/g, '');
}
//# sourceMappingURL=utils.js.map